@@ -13,7 +13,7 @@ from transformers import (
     set_seed,
 )
 from transformers.trainer_utils import get_last_checkpoint
-
+    
 
 class Trainer:
     def __init__(self, arguments):
@@ -38,17 +38,11 @@ class Trainer:
             self.arguments.mode = self.determine_model_type(
                 self.arguments.model_name_or_path)
             if self.arguments.mode == "seq2seq":
-                print("Training seq2seq language model")
-            elif self.arguments.mode == "clm":
-                print("Training causal language model")
+                print("Training seq2seq Language Model")
+            elif  self.arguments.mode == "clm":
+                print("Training causal Language Model")
             else:
                 print("Set TrainingArguments.mode to", self.arguments.mode)
-        try:
-            nproc = torch.distributed.get_world_size()
-            rank = torch.distributed.get_rank()
-            print("Process", rank, "of", nproc)
-        except Exception as e:
-            print("No distributed process detected:", e)
         # squeeze out more RAM to load larger models
         gc.collect()
         self.load_model()
@@ -106,32 +100,32 @@ class Trainer:
                 )
             if "valid" not in self.raw_datasets.keys() and self.arguments.validation_split > 0:
                 print("Auto-split validation set from training set:",
-                      self.arguments.validation_split, "%")
-                self.raw_datasets["valid"] = load_dataset(
+                      self.arguments.validation_split*100, "%")
+                full_dataset = load_dataset(
                     extension,
                     data_files=data_files,
-                    split=f"train[:{self.arguments.validation_split}%]",
+                    split="train",
                     cache_dir=self.arguments.cache_dir,
                 )
-                self.raw_datasets["train"] = load_dataset(
-                    extension,
-                    data_files=data_files,
-                    split=f"train[{self.arguments.validation_split}%:]",
-                    cache_dir=self.arguments.cache_dir,
-                )
-        try:
-            nproc = torch.distributed.get_world_size()
-            if nproc > 1:
+                split_datasets = full_dataset.train_test_split(test_size=self.arguments.validation_split)
+                self.raw_datasets["valid"] = split_datasets["test"]
+                self.raw_datasets["train"] = split_datasets["train"]
+            distributed = torch.distributed.is_initialized()
+            print("Distributed training:", distributed)
+            if distributed:
+                n_proc = torch.distributed.get_world_size()
                 rank = torch.distributed.get_rank()
-                print("Distributed setting: rank", rank, "of", nproc)
-                self.raw_datasets = self.raw_datasets.shard(
-                    num_shards=nproc, index=rank)
-        except Exception as e:
-            print("No sharding of dataset:", e)
-
+                print("Shard", rank+1, "of total", n_proc)
+                if "train" in self.raw_datasets.keys():
+                    self.raw_datasets["train"] = self.raw_datasets["train"].shard(num_shards=n_proc,
+                                                                                  index=rank)
+                if "valid" in self.raw_datasets.keys():
+                    self.raw_datasets["valid"] = self.raw_datasets["valid"].shard(num_shards=n_proc,
+                                                                                  index=rank)
+            
     def GradCheckpoint(self):
         self.arguments.gradient_checkpointing = True
-
+        
     def FreezeEmbeds(self):
         self.freeze(embeddings=True)
 
@@ -142,7 +136,7 @@ class Trainer:
     def unfreeze_params(self, module):
         for par in module.parameters():
             par.requires_grad = True
-
+            
     def get_embedding_layers(self):
         embedding_layers = []
         try:
@@ -151,9 +145,6 @@ class Trainer:
             print(e, "(probably not a encoder-decoder model)")
         try:
             embedding_layers.append(self.model.transformer.wte)
-        except Exception as e:
-            print(e, "(probably not a GPT-Neo/GPT-J model)")
-        try:
             embedding_layers.append(self.model.transformer.wpe)
         except Exception as e:
             print(e, "(probably not a GPT-Neo model)")
@@ -162,16 +153,16 @@ class Trainer:
     def freeze(self, encoder=None, decoder=None, embeddings=None):
         if encoder:
             self.freeze_params(self.model.encoder)
-        elif encoder == False:
+        elif encoder==False:
             self.unfreeze_params(self.model.encoder)
         if decoder:
             self.freeze_params(self.model.decoder)
-        elif decoder == False:
+        elif decoder==False:
             self.unfreeze_params(self.model.decoder)
         for el in self.get_embedding_layers():
             if embeddings:
                 self.freeze_params(el)
-            elif embeddings == False:
+            elif embeddings==False:
                 self.unfreeze_params(el)
 
     def resize_token_embeddings_layer(self, round_up=True):
@@ -304,7 +295,6 @@ class Trainer:
                 from_tf=bool(".ckpt" in self.arguments.model_name_or_path),
                 config=self.config,
                 cache_dir=self.arguments.cache_dir,
-                low_cpu_mem_usage=self.arguments.load_model_low_ram
             )
         elif self.arguments.mode == "clm":
             self.model = transformers.AutoModelForCausalLM.from_pretrained(
@@ -312,14 +302,13 @@ class Trainer:
                 from_tf=bool(".ckpt" in self.arguments.model_name_or_path),
                 config=self.config,
                 cache_dir=self.arguments.cache_dir,
-                low_cpu_mem_usage=self.arguments.load_model_low_ram
             )
         else:
             print("Model name:", self.arguments.model_name_or_path)
             print("Training mode:", self.arguments.mode)
             NotImplementedError(
                 "Unable to load this type of model for this training mode")
-
+            
         if self.arguments.model_parallel_gpus > 1:
             print("Model parallel on", self.arguments.model_parallel_gpus, "GPU:")
             device_map = {}
